/*
 *  Uzebox Default Patches
 *  Copyright (C) 2008  Alec Bourque
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*
	Patches are made of a command stream made of 3 bytes per command:
		1=delta time
		2=command
		3=command parameter

	Patches must start with 1 byte describing the sound type:
		0=wave channel (i.e.; channel 0,1 and 2)
		1=noise channel (channel 3)
		2=PCM (channel 3)
		->For type=2 two more byte follows in order: sample adress low byte, sample adress hi byte

	It must end with <0,PATCH_END> and this command takes
	only two bytes (no parameter).
*/

//External PCM samples
#include "spark.inc"
#include "bomb.inc"

//INST: triangular - no env
const char patch00[] PROGMEM ={	

0,PC_WAVE,8,
0,PC_ENV_SPEED,-10,
0,PC_PITCH,90,
1,PC_PITCH,78,
1,PC_PITCH,75,
1,PC_PITCH,70,
1,PC_PITCH,65,
1,PC_PITCH,55,
1,PC_PITCH,45,


1,PC_NOTE_CUT,
0,PATCH_END
};

const char patch01[] PROGMEM ={	

0,PC_WAVE,3,
0,PC_ENV_SPEED,-20,
0,PC_PITCH,50,
1,PC_PITCH,30,
1,PC_PITCH,10,
1,PC_PITCH,50,
1,PC_PITCH,30,

1,PC_NOTE_CUT,
0,PATCH_END
};

const char patch02[] PROGMEM ={	

0,PC_WAVE,3,
0,PC_ENV_SPEED,-10,

0,PC_PITCH,62,
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 


1,PC_NOTE_DOWN,10,
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 


1,PC_NOTE_DOWN,2,
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 



1,PC_NOTE_DOWN,10,
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 


1,PC_NOTE_DOWN,5,
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 



1,PC_NOTE_DOWN,2,
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 
1,PC_NOTE_UP,2, 



1,PC_NOTE_CUT,0,

0,PATCH_END 

};

const char patch03[] PROGMEM ={	

0,PC_WAVE,2,
1,PC_NOTE_HOLD,0,
1,PC_ENV_SPEED,-32,
0,PATCH_END
};

const char patch04[] PROGMEM ={	

0,PC_WAVE,2,
1,PC_NOTE_HOLD,0,
1,PC_ENV_SPEED,-32,
0,PATCH_END
};







const struct PatchStruct patches[] PROGMEM = {

{0,NULL,patch00,0,0},
{0,NULL,patch01,0,0},
{0,NULL,patch02,0,0},
{0,NULL,patch03,0,0},
{0,NULL,patch04,0,0},

{2,spark,NULL,sizeof_spark,sizeof_spark},
{2,bomb,NULL,sizeof_bomb,sizeof_bomb}

};









